Linux Media Controller development
 help / color / mirror / Atom feed
* [PATCH] rc-videomate-m1f.c Rename to match remote controler name
@ 2012-01-06 16:32 Samuel Rakitničan
  2012-01-06 21:34 ` Samuel Rakitničan
  2014-04-05 16:34 ` Ramiro Morales
  0 siblings, 2 replies; 4+ messages in thread
From: Samuel Rakitničan @ 2012-01-06 16:32 UTC (permalink / raw)
  To: linux-media@vger.kernel.org

[-- Attachment #1: Type: text/plain, Size: 371 bytes --]

This remote was added with support for card Compro VideoMate M1F.

This remote is shipped with various Compro cards, not this one only.

Furthermore this remote can be bought separately under name Compro
VideoMate K100.
	http://compro.com.tw/en/product/k100/k100.html

So give it a proper name.


Signed-off-by: Samuel Rakitničan <samuel.rakitnican@gmail.com>

[-- Attachment #2: k100.diff --]
[-- Type: application/octet-stream, Size: 3440 bytes --]

diff --git a/drivers/media/rc/keymaps/Makefile b/drivers/media/rc/keymaps/Makefile
index 36e4d5e..82d898a 100644
--- a/drivers/media/rc/keymaps/Makefile
+++ b/drivers/media/rc/keymaps/Makefile
@@ -85,7 +85,7 @@ obj-$(CONFIG_RC_MAP) += rc-adstech-dvb-t-pci.o \
 			rc-trekstor.o \
 			rc-tt-1500.o \
 			rc-twinhan1027.o \
-			rc-videomate-m1f.o \
+			rc-videomate-k100.o \
 			rc-videomate-s350.o \
 			rc-videomate-tv-pvr.o \
 			rc-winfast.o \
diff --git a/drivers/media/video/saa7134/saa7134-input.c b/drivers/media/video/saa7134/saa7134-input.c
index 1b15b0d..22ecd72 100644
--- a/drivers/media/video/saa7134/saa7134-input.c
+++ b/drivers/media/video/saa7134/saa7134-input.c
@@ -755,7 +755,7 @@ int saa7134_input_init1(struct saa7134_dev *dev)
 		polling      = 50; /* ms */
 		break;
 	case SAA7134_BOARD_VIDEOMATE_M1F:
-		ir_codes     = RC_MAP_VIDEOMATE_M1F;
+		ir_codes     = RC_MAP_VIDEOMATE_K100;
 		mask_keycode = 0x0ff00;
 		mask_keyup   = 0x040000;
 		break;
diff --git a/include/media/rc-map.h b/include/media/rc-map.h
index 183d701..f688bde 100644
--- a/include/media/rc-map.h
+++ b/include/media/rc-map.h
@@ -147,7 +147,7 @@ void rc_map_init(void);
 #define RC_MAP_TREKSTOR                  "rc-trekstor"
 #define RC_MAP_TT_1500                   "rc-tt-1500"
 #define RC_MAP_TWINHAN_VP1027_DVBS       "rc-twinhan1027"
-#define RC_MAP_VIDEOMATE_M1F             "rc-videomate-m1f"
+#define RC_MAP_VIDEOMATE_K100            "rc-videomate-k100"
 #define RC_MAP_VIDEOMATE_S350            "rc-videomate-s350"
 #define RC_MAP_VIDEOMATE_TV_PVR          "rc-videomate-tv-pvr"
 #define RC_MAP_WINFAST                   "rc-winfast"

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [PATCH] rc-videomate-m1f.c Rename to match remote controler name
  2012-01-06 16:32 [PATCH] rc-videomate-m1f.c Rename to match remote controler name Samuel Rakitničan
@ 2012-01-06 21:34 ` Samuel Rakitničan
  2014-04-05 16:34 ` Ramiro Morales
  1 sibling, 0 replies; 4+ messages in thread
From: Samuel Rakitničan @ 2012-01-06 21:34 UTC (permalink / raw)
  To: linux-media@vger.kernel.org

[-- Attachment #1: Type: text/plain, Size: 532 bytes --]

On Fri, 06 Jan 2012 17:32:06 +0100, Samuel Rakitničan  
<samuel.rakitnican@gmail.com> wrote:

> This remote was added with support for card Compro VideoMate M1F.
>
> This remote is shipped with various Compro cards, not this one only.
>
> Furthermore this remote can be bought separately under name Compro
> VideoMate K100.
> 	http://compro.com.tw/en/product/k100/k100.html
>
> So give it a proper name.
>
>
> Signed-off-by: Samuel Rakitničan <samuel.rakitnican@gmail.com>

Resending a mail version for patchwork..

[-- Attachment #2: k100.diff --]
[-- Type: text/plain, Size: 3440 bytes --]

diff --git a/drivers/media/rc/keymaps/Makefile b/drivers/media/rc/keymaps/Makefile
index 36e4d5e..82d898a 100644
--- a/drivers/media/rc/keymaps/Makefile
+++ b/drivers/media/rc/keymaps/Makefile
@@ -85,7 +85,7 @@ obj-$(CONFIG_RC_MAP) += rc-adstech-dvb-t-pci.o \
 			rc-trekstor.o \
 			rc-tt-1500.o \
 			rc-twinhan1027.o \
-			rc-videomate-m1f.o \
+			rc-videomate-k100.o \
 			rc-videomate-s350.o \
 			rc-videomate-tv-pvr.o \
 			rc-winfast.o \
diff --git a/drivers/media/video/saa7134/saa7134-input.c b/drivers/media/video/saa7134/saa7134-input.c
index 1b15b0d..22ecd72 100644
--- a/drivers/media/video/saa7134/saa7134-input.c
+++ b/drivers/media/video/saa7134/saa7134-input.c
@@ -755,7 +755,7 @@ int saa7134_input_init1(struct saa7134_dev *dev)
 		polling      = 50; /* ms */
 		break;
 	case SAA7134_BOARD_VIDEOMATE_M1F:
-		ir_codes     = RC_MAP_VIDEOMATE_M1F;
+		ir_codes     = RC_MAP_VIDEOMATE_K100;
 		mask_keycode = 0x0ff00;
 		mask_keyup   = 0x040000;
 		break;
diff --git a/include/media/rc-map.h b/include/media/rc-map.h
index 183d701..f688bde 100644
--- a/include/media/rc-map.h
+++ b/include/media/rc-map.h
@@ -147,7 +147,7 @@ void rc_map_init(void);
 #define RC_MAP_TREKSTOR                  "rc-trekstor"
 #define RC_MAP_TT_1500                   "rc-tt-1500"
 #define RC_MAP_TWINHAN_VP1027_DVBS       "rc-twinhan1027"
-#define RC_MAP_VIDEOMATE_M1F             "rc-videomate-m1f"
+#define RC_MAP_VIDEOMATE_K100            "rc-videomate-k100"
 #define RC_MAP_VIDEOMATE_S350            "rc-videomate-s350"
 #define RC_MAP_VIDEOMATE_TV_PVR          "rc-videomate-tv-pvr"
 #define RC_MAP_WINFAST                   "rc-winfast"

^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [PATCH] rc-videomate-m1f.c Rename to match remote controler name
  2012-01-06 16:32 [PATCH] rc-videomate-m1f.c Rename to match remote controler name Samuel Rakitničan
  2012-01-06 21:34 ` Samuel Rakitničan
@ 2014-04-05 16:34 ` Ramiro Morales
  2014-04-05 16:43   ` Ramiro Morales
  1 sibling, 1 reply; 4+ messages in thread
From: Ramiro Morales @ 2014-04-05 16:34 UTC (permalink / raw)
  To: linux-media

Samuel Rakitničan <samuel.rakitnican <at> gmail.com> writes:

> 
> This remote was added with support for card Compro VideoMate M1F.
> 
> This remote is shipped with various Compro cards, not this one only.
> 
> Furthermore this remote can be bought separately under name Compro
> VideoMate K100.
> 	http://compro.com.tw/en/product/k100/k100.html
> 
> So give it a proper name.
> 
> Signed-off-by: Samuel Rakitničan <samuel.rakitnican <at> gmail.com>
> Attachment (k100.diff): application/octet-stream, 3440 bytes

This hasn't landed correctly. Two years later, the rename is still
implemented in a halfway fashion on the kernel source tree:

The drivers/media/rc/keymaps/Makefile file still mentions
rc-videomate-m1f.o and there is still a drivers/media/rc/keymaps
/rc-videomate-m1f.c file that should be named rc-videomate-m1f.c instead.

This renders the driver and the remote control unusable for final users
and forces those with some knowledge to solve it e.g. by creating a
/etc/modprobe.d/compro-rc-alias.conf file containing:

  alias rc-videomate-k100 rc-videomate-m1f

diff --git a/drivers/media/rc/keymaps/rc-videomate-k100.c b/drivers/media/rc/keymaps/rc-videomate-k100.c
index 3bd1de1..23ee05e 100644
--- a/drivers/media/rc/keymaps/rc-videomate-k100.c
+++ b/drivers/media/rc/keymaps/rc-videomate-k100.c
@@ -1,4 +1,4 @@
 /* videomate-m1f.h - Keytable for videomate_m1f Remote Controller
  *
  * keymap imported from ir-keymaps.c
  *
@@ -13,7 +13,7 @@
 #include <media/rc-map.h>
 #include <linux/module.h>
 
-static struct rc_map_table videomate_m1f[] = {
+static struct rc_map_table videomate_k100[] = {
 	{ 0x01, KEY_POWER },
 	{ 0x31, KEY_TUNER },
 	{ 0x33, KEY_VIDEO },
@@ -67,27 +67,27 @@ static struct rc_map_table videomate_m1f[] = {
 	{ 0x18, KEY_TEXT },
 };
 
-static struct rc_map_list videomate_m1f_map = {
+static struct rc_map_list videomate_k100_map = {
 	.map = {
-		.scan    = videomate_m1f,
-		.size    = ARRAY_SIZE(videomate_m1f),
+		.scan    = videomate_k100,
+		.size    = ARRAY_SIZE(videomate_k100),
 		.rc_type = RC_TYPE_UNKNOWN,     /* Legacy IR type */
-		.name    = RC_MAP_VIDEOMATE_M1F,
+		.name    = RC_MAP_VIDEOMATE_K100,
 	}
 };
 
-static int __init init_rc_map_videomate_m1f(void)
+static int __init init_rc_map_videomate_k100(void)
 {
-	return rc_map_register(&videomate_m1f_map);
+	return rc_map_register(&videomate_k100_map);
 }
 
-static void __exit exit_rc_map_videomate_m1f(void)
+static void __exit exit_rc_map_videomate_k100(void)
 {
-	rc_map_unregister(&videomate_m1f_map);
+	rc_map_unregister(&videomate_k100_map);
 }
 
-module_init(init_rc_map_videomate_m1f)
-module_exit(exit_rc_map_videomate_m1f)
+module_init(init_rc_map_videomate_k100)
+module_exit(exit_rc_map_videomate_k100)
 
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Pavel Osnova <pvosnova@gmail.com>");
@@ -1,4 +1,4 @@
-/* videomate-m1f.h - Keytable for videomate_m1f Remote Controller
+/* videomate-k100.h - Keytable for videomate_k100 Remote Controller
  *
  * keymap imported from ir-keymaps.c
diff --git a/drivers/media/rc/keymaps/rc-videomate-k100.c b/drivers/media/rc/keymaps/rc-videomate-k100.c
index 3bd1de1..23ee05e 100644
--- a/drivers/media/rc/keymaps/rc-videomate-k100.c
+++ b/drivers/media/rc/keymaps/rc-videomate-k100.c
@@ -1,4 +1,4 @@
 /* videomate-m1f.h - Keytable for videomate_m1f Remote Controller
  *
  * keymap imported from ir-keymaps.c
  *
@@ -13,7 +13,7 @@
 #include <media/rc-map.h>
 #include <linux/module.h>
 
-static struct rc_map_table videomate_m1f[] = {
+static struct rc_map_table videomate_k100[] = {
 	{ 0x01, KEY_POWER },
 	{ 0x31, KEY_TUNER },
 	{ 0x33, KEY_VIDEO },
@@ -67,27 +67,27 @@ static struct rc_map_table videomate_m1f[] = {
 	{ 0x18, KEY_TEXT },
 };
 
-static struct rc_map_list videomate_m1f_map = {
+static struct rc_map_list videomate_k100_map = {
 	.map = {
-		.scan    = videomate_m1f,
-		.size    = ARRAY_SIZE(videomate_m1f),
+		.scan    = videomate_k100,
+		.size    = ARRAY_SIZE(videomate_k100),
 		.rc_type = RC_TYPE_UNKNOWN,     /* Legacy IR type */
-		.name    = RC_MAP_VIDEOMATE_M1F,
+		.name    = RC_MAP_VIDEOMATE_K100,
 	}
 };
 
-static int __init init_rc_map_videomate_m1f(void)
+static int __init init_rc_map_videomate_k100(void)
 {
-	return rc_map_register(&videomate_m1f_map);
+	return rc_map_register(&videomate_k100_map);
 }
 
-static void __exit exit_rc_map_videomate_m1f(void)
+static void __exit exit_rc_map_videomate_k100(void)
 {
-	rc_map_unregister(&videomate_m1f_map);
+	rc_map_unregister(&videomate_k100_map);
 }
 
-module_init(init_rc_map_videomate_m1f)
-module_exit(exit_rc_map_videomate_m1f)
+module_init(init_rc_map_videomate_k100)
+module_exit(exit_rc_map_videomate_k100)
 
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Pavel Osnova <pvosnova@gmail.com>");
@@ -1,4 +1,4 @@
-/* videomate-m1f.h - Keytable for videomate_m1f Remote Controller
+/* videomate-k100.h - Keytable for videomate_k100 Remote Controller
  *
  * keymap imported from ir-keymaps.c
diff -ruN linux-source-3.13.0.orig/drivers/media/rc/keymaps/Makefile
linux-source-3.13.0/drivers/media/rc/keymaps/Makefile
--- linux-source-3.13.0.orig/drivers/media/rc/keymaps/Makefile  2014-01-19
23:40:07.000000000 -0300
+++ linux-source-3.13.0/drivers/media/rc/keymaps/Makefile       2014-03-23
22:33:31.871184552 -0300
@@ -94,7 +94,7 @@
                        rc-trekstor.o \
                        rc-tt-1500.o \
                        rc-twinhan1027.o \
-                       rc-videomate-m1f.o \
+                       rc-videomate-k100.o \
                        rc-videomate-s350.o \
                        rc-videomate-tv-pvr.o \
                        rc-winfast.o \
diff -ruN
linux-source-3.13.0.orig/drivers/media/rc/keymaps/rc-videomate-k100.c
linux-source-3.13.0/drivers/media/rc/keymaps/rc-videomate-k100.c
--- linux-source-3.13.0.orig/drivers/media/rc/keymaps/rc-videomate-k100.c  
    1969-12-31 21:00:00.000000000 -0300
+++ linux-source-3.13.0/drivers/media/rc/keymaps/rc-videomate-k100.c   
2014-01-19 23:40:07.000000000 -0300
@@ -0,0 +1,93 @@
+/* videomate-k100.h - Keytable for videomate_k100 Remote Controller
+ *
+ * keymap imported from ir-keymaps.c
+ *
+ * Copyright (c) 2010 by Pavel Osnova <pvosnova@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ */
+
+#include <media/rc-map.h>
+#include <linux/module.h>
+
+static struct rc_map_table videomate_k100[] = {
+       { 0x01, KEY_POWER },
+       { 0x31, KEY_TUNER },
+       { 0x33, KEY_VIDEO },
+       { 0x2f, KEY_RADIO },
+       { 0x30, KEY_CAMERA },
+       { 0x2d, KEY_NEW }, /* TV record button */
+       { 0x17, KEY_CYCLEWINDOWS },
+       { 0x2c, KEY_ANGLE },
+       { 0x2b, KEY_LANGUAGE },
+       { 0x32, KEY_SEARCH }, /* '...' button */
+       { 0x11, KEY_UP },
+       { 0x13, KEY_LEFT },
+       { 0x15, KEY_OK },
+       { 0x14, KEY_RIGHT },
+       { 0x12, KEY_DOWN },
+       { 0x16, KEY_BACKSPACE },
+       { 0x02, KEY_ZOOM }, /* WIN key */
+       { 0x04, KEY_INFO },
+       { 0x05, KEY_VOLUMEUP },
+       { 0x03, KEY_MUTE },
+       { 0x07, KEY_CHANNELUP },
+       { 0x06, KEY_VOLUMEDOWN },
+       { 0x08, KEY_CHANNELDOWN },
+       { 0x0c, KEY_RECORD },
+       { 0x0e, KEY_STOP },
+       { 0x0a, KEY_BACK },
+       { 0x0b, KEY_PLAY },
+       { 0x09, KEY_FORWARD },
+       { 0x10, KEY_PREVIOUS },
+       { 0x0d, KEY_PAUSE },
+       { 0x0f, KEY_NEXT },
+       { 0x1e, KEY_1 },
+       { 0x1f, KEY_2 },
+       { 0x20, KEY_3 },
+       { 0x21, KEY_4 },
+       { 0x22, KEY_5 },
+       { 0x23, KEY_6 },
+       { 0x24, KEY_7 },
+       { 0x25, KEY_8 },
+       { 0x26, KEY_9 },
+       { 0x2a, KEY_NUMERIC_STAR }, /* * key */
+       { 0x1d, KEY_0 },
+       { 0x29, KEY_SUBTITLE }, /* # key */
+       { 0x27, KEY_CLEAR },
+       { 0x34, KEY_SCREEN },
+       { 0x28, KEY_ENTER },
+       { 0x19, KEY_RED },
+       { 0x1a, KEY_GREEN },
+       { 0x1b, KEY_YELLOW },
+       { 0x1c, KEY_BLUE },
+       { 0x18, KEY_TEXT },
+};
+
+static struct rc_map_list videomate_k100_map = {
+       .map = {
+               .scan    = videomate_k100,
+               .size    = ARRAY_SIZE(videomate_k100),
+               .rc_type = RC_TYPE_UNKNOWN,     /* Legacy IR type */
+               .name    = RC_MAP_VIDEOMATE_K100,
+       }
+};
+
+static int __init init_rc_map_videomate_k100(void)
+{
+       return rc_map_register(&videomate_k100_map);
+}
+
+static void __exit exit_rc_map_videomate_k100(void)
+{
+       rc_map_unregister(&videomate_k100_map);
+}
+
+module_init(init_rc_map_videomate_k100)
+module_exit(exit_rc_map_videomate_k100)
+
+MODULE_LICENSE("GPL");
+MODULE_AUTHOR("Pavel Osnova <pvosnova@gmail.com>");
diff -ruN
linux-source-3.13.0.orig/drivers/media/rc/keymaps/rc-videomate-m1f.c
linux-source-3.13.0/drivers/media/rc/keymaps/rc-videomate-m1f.c
--- linux-source-3.13.0.orig/drivers/media/rc/keymaps/rc-videomate-m1f.c   
    2014-01-19 23:40:07.000000000 -0300
+++ linux-source-3.13.0/drivers/media/rc/keymaps/rc-videomate-m1f.c    
1969-12-31 21:00:00.000000000 -0300
@@ -1,93 +0,0 @@
-/* videomate-k100.h - Keytable for videomate_k100 Remote Controller
- *
- * keymap imported from ir-keymaps.c
- *
- * Copyright (c) 2010 by Pavel Osnova <pvosnova@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- */
-
-#include <media/rc-map.h>
-#include <linux/module.h>
-
-static struct rc_map_table videomate_k100[] = {
-       { 0x01, KEY_POWER },
-       { 0x31, KEY_TUNER },
-       { 0x33, KEY_VIDEO },
-       { 0x2f, KEY_RADIO },
-       { 0x30, KEY_CAMERA },
-       { 0x2d, KEY_NEW }, /* TV record button */
-       { 0x17, KEY_CYCLEWINDOWS },
-       { 0x2c, KEY_ANGLE },
-       { 0x2b, KEY_LANGUAGE },
-       { 0x32, KEY_SEARCH }, /* '...' button */
-       { 0x11, KEY_UP },
-       { 0x13, KEY_LEFT },
-       { 0x15, KEY_OK },
-       { 0x14, KEY_RIGHT },
-       { 0x12, KEY_DOWN },
-       { 0x16, KEY_BACKSPACE },
-       { 0x02, KEY_ZOOM }, /* WIN key */
-       { 0x04, KEY_INFO },
-       { 0x05, KEY_VOLUMEUP },
-       { 0x03, KEY_MUTE },
-       { 0x07, KEY_CHANNELUP },
-       { 0x06, KEY_VOLUMEDOWN },
-       { 0x08, KEY_CHANNELDOWN },
-       { 0x0c, KEY_RECORD },
-       { 0x0e, KEY_STOP },
-       { 0x0a, KEY_BACK },
-       { 0x0b, KEY_PLAY },
-       { 0x09, KEY_FORWARD },
-       { 0x10, KEY_PREVIOUS },
-       { 0x0d, KEY_PAUSE },
-       { 0x0f, KEY_NEXT },
-       { 0x1e, KEY_1 },
-       { 0x1f, KEY_2 },
-       { 0x20, KEY_3 },
-       { 0x21, KEY_4 },
-       { 0x22, KEY_5 },
-       { 0x23, KEY_6 },
-       { 0x24, KEY_7 },
-       { 0x25, KEY_8 },
-       { 0x26, KEY_9 },
-       { 0x2a, KEY_NUMERIC_STAR }, /* * key */
-       { 0x1d, KEY_0 },
-       { 0x29, KEY_SUBTITLE }, /* # key */
-       { 0x27, KEY_CLEAR },
-       { 0x34, KEY_SCREEN },
-       { 0x28, KEY_ENTER },
-       { 0x19, KEY_RED },
-       { 0x1a, KEY_GREEN },
-       { 0x1b, KEY_YELLOW },
-       { 0x1c, KEY_BLUE },
-       { 0x18, KEY_TEXT },
-};
-
-static struct rc_map_list videomate_k100_map = {
-       .map = {
-               .scan    = videomate_k100,
-               .size    = ARRAY_SIZE(videomate_k100),
-               .rc_type = RC_TYPE_UNKNOWN,     /* Legacy IR type */
-               .name    = RC_MAP_VIDEOMATE_K100,
-       }
-};
-
-static int __init init_rc_map_videomate_k100(void)
-{
-       return rc_map_register(&videomate_k100_map);
-}
-
-static void __exit exit_rc_map_videomate_k100(void)
-{
-       rc_map_unregister(&videomate_k100_map);
-}
-
-module_init(init_rc_map_videomate_k100)
-module_exit(exit_rc_map_videomate_k100)
-
-MODULE_LICENSE("GPL");
-MODULE_AUTHOR("Pavel Osnova <pvosnova@gmail.com>");



Regards,

-- 
Ramiro


^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [PATCH] rc-videomate-m1f.c Rename to match remote controler name
  2014-04-05 16:34 ` Ramiro Morales
@ 2014-04-05 16:43   ` Ramiro Morales
  0 siblings, 0 replies; 4+ messages in thread
From: Ramiro Morales @ 2014-04-05 16:43 UTC (permalink / raw)
  To: linux-media

On Sat, Apr 5, 2014 at 1:34 PM, Ramiro Morales <cramm0@gmail.com> wrote:
> This hasn't landed correctly. Two years later, the rename is still
> implemented in a halfway fashion on the kernel source tree:
>
> The drivers/media/rc/keymaps/Makefile file still mentions
> rc-videomate-m1f.o and there is still a drivers/media/rc/keymaps
> /rc-videomate-m1f.c file that should be named rc-videomate-m1f.c instead.

See:

https://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/tree/drivers/media/rc/keymaps/Makefile?id=refs/tags/v3.14#n97

and

https://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/tree/drivers/media/rc/keymaps/rc-videomate-m1f.c?id=refs/tags/v3.14

-- 
Ramiro Morales
@ramiromorales

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2014-04-05 16:51 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2012-01-06 16:32 [PATCH] rc-videomate-m1f.c Rename to match remote controler name Samuel Rakitničan
2012-01-06 21:34 ` Samuel Rakitničan
2014-04-05 16:34 ` Ramiro Morales
2014-04-05 16:43   ` Ramiro Morales

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox